@@ -64,7 +64,8 @@ sub _module_path {
 sub _locale_path_from_module {
   my $module_path = _module_path(shift);
   my ($vol, $dir, $file) = File::Spec->splitpath($module_path);
-  my $locale_path = File::Spec->catfile($dir, 'locale','*.*');
+  #my $locale_path = File::Spec->catfile($dir, 'locale','*.*');
+  my $locale_path = File::Spec->catpath($vol, $dir, File::Spec->catfile('locale', '*.*'));
   return $locale_path;
 }
 
